forecast_multivariate ML estimationA function to create the multivariate forecast methods arguments list for user manipulation.
instantiate.forecast_multivariate.ml.control_panel(
covariates = NULL,
rolling.window = NULL,
horizon = NULL
)int: the number of features that will go into the model
int: size of rolling window, NA if expanding window is used
int: number of periods into the future to forecast
forecast_multivariate.ml.control_panel