instantiate.forecast_combinations.control_panel: Create interface to control forecast_combine model estimation
Description
A function to create the forecast combination technique arguments list
for user manipulation.
Usage
instantiate.forecast_combinations.control_panel(covariates = NULL)
Arguments
covariates
int: the number of features that will go into the model
Value
forecast_combinations.control_panel